pub struct CorrelationMatrix { /* private fields */ }Expand description
Pairwise Pearson correlation matrix for a set of variables.
Implementations
Sourceimpl CorrelationMatrix
impl CorrelationMatrix
Sourcepub fn from_rows(rows: &[&[f64]]) -> Result<Self>
pub fn from_rows(rows: &[&[f64]]) -> Result<Self>
Build a correlation matrix from rows of observations.
Each inner slice is one variable’s observations (all must have the same length and at least 2 elements).
Sourcepub fn from_rows_labeled(rows: &[&[f64]], labels: &[&str]) -> Result<Self>
pub fn from_rows_labeled(rows: &[&[f64]], labels: &[&str]) -> Result<Self>
Build a labeled correlation matrix.