RankMethod

Enum RankMethod 

pub enum RankMethod {
    Average,
    Min,
    Max,
    Ordinal,
    Dense,
}
Strategy for handling tied values when ranking.

Variants



Average

Tied values receive the average of their would-be ranks (default for most statistical methods).



Min

Tied values receive the minimum rank in the group.



Max

Tied values receive the maximum rank in the group.



Ordinal

Tied values receive sequential ranks (first occurrence gets lower rank).



Dense

Like Min, but ranks always increase by 1 (no gaps).